library(ggplot2)
library(ggpubr)
library(RColorBrewer)

# data from "12_Feature_importance.zip"
ECM_env <- read.csv("ECM_env_imp.csv")
FM_env <- read.csv("FM_env_imp.csv")
AM_env <- read.csv("AM_env_imp.csv")
ERM_env <- read.csv("ERM_env_imp.csv")
ORM_env <- read.csv("ORM_env_imp.csv")
NM_env <- read.csv("NM_env_imp.csv")
OM_env <- read.csv("OM_env_imp.csv")
all_types_env <- read.csv("type_env_imp.csv")
all_status_env <- read.csv("status_env_imp.csv")

all_data_frames <- eapply(.GlobalEnv, is.data.frame)

for (df_name in names(all_data_frames)) {
  df <- get(df_name)
  df$cols[df$cols == "Solarradiation"] <- "Solar radiation"
  df$cols[df$cols == "WRB_nonsoil"] <- "Non soil"
  df <- df[order(-df$imp), ] 
  assign(df_name, df, envir = .GlobalEnv)  
}

color_palette <- brewer.pal(8, "Paired")

bar_color <- c("1"=color_palette[2],
           "2"=color_palette[1],
           "3"=color_palette[4],
           "4"=color_palette[3],
           "5"=color_palette[8])
legend_text <- c("Climate", "Climatic range", "Edaphic property", "Edaphic range", "Soil order")


theme_bar <- function(...) {
  theme_minimal() + theme(
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    panel.border = element_blank(),
    axis.line.x = element_line(colour = "grey"),
    axis.line.y = element_line(colour = "grey"),
    axis.ticks = element_line(colour = "black"),
    axis.text.x = element_text(size = 12, face = "bold"), 
    axis.text.y = element_text(size = 12, face = "bold"),
    legend.position="bottom",
    legend.box = "vertical",
    legend.text = element_text(size = 12),
    plot.margin = margin(0.3, 0.3, 0.3, 0.3, "cm"),
    ...
  )
}


p1 <- ggplot(data = AM_env[1:20,],aes(x = reorder(cols, X.1), y = X.1, fill = as.character(group))) +
  geom_bar(stat = "identity", color="lightgrey")+
  scale_fill_manual(name = "", values = bar_color, labels = legend_text)+
  theme_bar()

p1 <- p1 + 
  coord_flip()+ 
  labs( x = "", y = "")
p1

p2 <- ggplot(data = ECM_env[1:20,],aes(x = reorder(cols, X.1), y = X.1, fill = as.character(group))) +
  geom_bar(stat = "identity", color="lightgrey")+
  scale_fill_manual(name = "", values = bar_color, labels = legend_text)+
  theme_bar()

p2 <- p2 + 
  coord_flip()+ 
  labs( x = "", y = "")
p2

p <- ggarrange(p1, p2, labels = c("AM", "ECM"), ncol=2, nrow=1, common.legend = TRUE, legend="bottom")
ggsave("AMECM.tiff", device = "tiff", dpi = 300)

p1 <- ggplot(data = ERM_env[1:20,],aes(x = reorder(cols, X.1), y = X.1, fill = as.character(group))) +
  geom_bar(stat = "identity", color="lightgrey")+
  scale_fill_manual(name = "", values = bar_color, labels = legend_text)+
  theme_bar() 

p1 <- p1 + 
  coord_flip()+ 
  labs( x = "", y = "")
p1

p2 <- ggplot(data = NM_env[1:20,],aes(x = reorder(cols, X.1), y = X.1, fill = as.character(group))) +
  geom_bar(stat = "identity", color="lightgrey")+
  scale_fill_manual(name = "", values = bar_color, labels = legend_text)+
  theme_bar() 

p2 <- p2 + 
  coord_flip()+ 
  labs( x = "", y = "")
p2

p <- ggarrange(p1, p2, labels = c("ERM", "NM"), ncol=2, nrow=1, common.legend = TRUE, legend="bottom")
ggsave("ERMNM.tiff", device = "tiff", dpi = 300)

p1 <- ggplot(data = FM_env[1:20,],aes(x = reorder(cols, X.1), y = X.1, fill = as.character(group))) +
  geom_bar(stat = "identity", color="lightgrey")+
  scale_fill_manual(name = "", values = bar_color, labels = legend_text)+
  theme_bar() 

p1 <- p1 + 
  coord_flip()+ 
  labs( x = "", y = "")
p1

p2 <- ggplot(data = OM_env[1:20,],aes(x = reorder(cols, X.1), y = X.1, fill = as.character(group))) +
  geom_bar(stat = "identity", color="lightgrey")+
  scale_fill_manual(name = "", values = bar_color, labels = legend_text)+
  theme_bar() 

p2 <- p2 + 
  coord_flip()+ 
  labs( x = "", y = "")
p2

p <- ggarrange(p1, p2, labels = c("FM", "OM"), ncol=2, nrow=1, common.legend = TRUE, legend="bottom")
ggsave("FMOM.tiff", device = "tiff", dpi = 300)

p1 <- ggplot(data = all_types_env[1:20,],aes(x = reorder(cols, X.1), y = X.1, fill = as.character(group))) +
  geom_bar(stat = "identity", color="lightgrey")+
  scale_fill_manual(name = "", values = bar_color, labels = legend_text)+
  theme_bar() 

p1 <- p1 + 
  coord_flip()+ 
  labs( x = "", y = "")
p1

p2 <- ggplot(data = all_status_env[1:20,],aes(x = reorder(cols, X.1), y = X.1, fill = as.character(group))) +
  geom_bar(stat = "identity", color="lightgrey")+
  scale_fill_manual(name = "", values = bar_color, labels = legend_text)+
  theme_bar() 

p2 <- p2 + 
  coord_flip()+ 
  labs( x = "", y = "")
p2

p <- ggarrange(p1, p2, labels = c("Type", "Status"), ncol=2, nrow=1, common.legend = TRUE, legend="bottom")
ggsave("TypeStatus.tiff", device = "tiff", dpi = 300)
